==> cscec5b-dataexchange-api-3.0.1-20221018.130325-50-sources.jar: com/ejianc/business/dataexchange/api/ICmContractApi.java <==
package com.ejianc.business.dataexchange.api;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.dataexchange.hystrix.CmContractHystrix;
import com.ejianc.business.dataexchange.vo.CmContract;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * 五局合同接口
 *
 * @author brin
 *
 */
@FeignClient(name= "cscec5b-dataexchange-web", url="${common.env.feign-client-url}", path="cscec5b-dataexchange-web", fallback = CmContractHystrix.class)
public interface ICmContractApi {

	/**
	 * 物资合同参照查询
	 * @param pkCorp	公司
	 * @return
	 */
	@GetMapping(value = "/api/queryMatContractRef")
	public CommonResponse<IPage<CmContract>> queryMatContractRef(
            @RequestParam(value = "pkCorp", required = false) String pkCorp,
			@RequestParam(defaultValue = "1") Integer pageNumber,
			@RequestParam(defaultValue = "10") Integer pageSize,
			@RequestParam(value = "condition", required = false) String condition,
			@RequestParam(value = "searchText", required = false) String searchText);

	/**
	 * 分包合同参照查询
	 * @param pkCorp	公司
	 * @return
	 */
	@GetMapping(value = "/api/querySubContractRef")
	public CommonResponse<IPage<CmContract>> querySubContractRef(
			@RequestParam(value = "pkCorp", required = false) String pkCorp,
			@RequestParam(defaultValue = "1") Integer pageNumber,
			@RequestParam(defaultValue = "10") Integer pageSize,
			@RequestParam(value = "condition", required = false) String condition,
			@RequestParam(value = "searchText", required = false) String searchText);

	/**
	 * 分包、物资、设备合同参照查询
	 * @param pkCorp	公司
	 * @return
	 */
	@GetMapping(value = "/api/queryContractRef")
	public CommonResponse<IPage<CmContract>> queryContractRef(
			@RequestParam(value = "pkCorp", required = false) String pkCorp,
			@RequestParam(defaultValue = "1") Integer pageNumber,
			@RequestParam(defaultValue = "10") Integer pageSize,
			@RequestParam(value = "condition", required = false) String condition,
			@RequestParam(value = "searchText", required = false) String searchText);

	@GetMapping(value = "/api/queryMatContractById")
	public CommonResponse<CmContract> queryMatContractById(
			@RequestParam(value = "contractId") String contractId
		);

	/**
	 * 分包合同参照查询
	 * @param pkCorp	公司
	 * @return
	 */
	@GetMapping(value = "/api/querySubContractByCorp")
	public CommonResponse<IPage<CmContract>> querySubContractByCorp(
			@RequestParam(value = "pkCorp", required = false) String pkCorp,
			@RequestParam(defaultValue = "1") Integer pageNumber,
			@RequestParam(defaultValue = "10") Integer pageSize,
			@RequestParam(value = "condition", required = false) String condition,
			@RequestParam(value = "searchText", required = false) String searchText);

}

==> cscec5b-dataexchange-api-3.0.1-20221024.085845-65-sources.jar: com/ejianc/business/dataexchange/api/ICmContractApi.java <==
package com.ejianc.business.dataexchange.api;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.dataexchange.hystrix.CmContractHystrix;
import com.ejianc.business.dataexchange.vo.CmContract;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * 五局合同接口
 *
 * @author brin
 *
 */
@FeignClient(name= "cscec5b-dataexchange-web", url="${common.env.feign-client-url}", path="cscec5b-dataexchange-web", fallback = CmContractHystrix.class)
public interface ICmContractApi {

	/**
	 * 物资合同参照查询
	 * @param pkCorp	公司
	 * @return
	 */
	@GetMapping(value = "/api/queryMatContractRef")
	public CommonResponse<IPage<CmContract>> queryMatContractRef(
            @RequestParam(value = "pkCorp", required = false) String pkCorp,
			@RequestParam(defaultValue = "1") Integer pageNumber,
			@RequestParam(defaultValue = "10") Integer pageSize,
			@RequestParam(value = "condition", required = false) String condition,
			@RequestParam(value = "searchText", required = false) String searchText);

	/**
	 * 分包合同参照查询
	 * @param pkCorp	公司
	 * @return
	 */
	@GetMapping(value = "/api/querySubContractRef")
	public CommonResponse<IPage<CmContract>> querySubContractRef(
			@RequestParam(value = "pkCorp", required = false) String pkCorp,
			@RequestParam(defaultValue = "1") Integer pageNumber,
			@RequestParam(defaultValue = "10") Integer pageSize,
			@RequestParam(value = "condition", required = false) String condition,
			@RequestParam(value = "searchText", required = false) String searchText);

	/**
	 * 分包、物资、设备合同参照查询
	 * @param pkCorp	公司
	 * @return
	 */
	@GetMapping(value = "/api/queryContractRef")
	public CommonResponse<IPage<CmContract>> queryContractRef(
			@RequestParam(value = "pkCorp", required = false) String pkCorp,
			@RequestParam(defaultValue = "1") Integer pageNumber,
			@RequestParam(defaultValue = "10") Integer pageSize,
			@RequestParam(value = "condition", required = false) String condition,
			@RequestParam(value = "searchText", required = false) String searchText);

	@GetMapping(value = "/api/queryMatContractById")
	public CommonResponse<CmContract> queryMatContractById(
			@RequestParam(value = "contractId") String contractId
		);

	/**
	 * 分包合同参照查询
	 * @param pkCorp	公司
	 * @return
	 */
	@GetMapping(value = "/api/querySubContractByCorp")
	public CommonResponse<IPage<CmContract>> querySubContractByCorp(
			@RequestParam(value = "pkCorp", required = false) String pkCorp,
			@RequestParam(defaultValue = "1") Integer pageNumber,
			@RequestParam(defaultValue = "10") Integer pageSize,
			@RequestParam(value = "condition", required = false) String condition,
			@RequestParam(value = "searchText", required = false) String searchText);


	/**
	 * 分包合同列表查询
	 * @param pkProject	项目
	 * @return
	 */
	@GetMapping(value = "/api/querySubContractList")
	public CommonResponse<List<CmContract>> querySubContractList(
			@RequestParam(value = "pkProject") String pkProject,
			@RequestParam(value = "searchText", required = false) String searchText);

}
